CustomTheme class
- Inheritance
-
- Object
- ThemeExtension<
CustomTheme> - CustomTheme
Constructors
- CustomTheme({CustomColors colors = const CustomColors(), CustomFontStyle fontStyle = const CustomFontStyle()})
-
const
- CustomTheme.of(BuildContext context)
-
factory
Properties
- colors → CustomColors
-
final
- fontStyle → CustomFontStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
buildTheme(
) → ThemeData -
copyWith(
{CustomFontStyle? fontStyle, CustomColors? colors}) → ThemeExtension< CustomTheme> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< CustomTheme> ? other, double t) → ThemeExtension<CustomTheme> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited